// (C) Copyright 2015 Moodle Pty Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { Injectable } from '@angular/core';
import { Camera, CameraOptions } from '@ionic-native/camera/ngx';

import { CoreEmulatorCaptureHelper } from './capture-helper';

/**
 * Emulates the Cordova Camera plugin in browser.
 */
@Injectable()
export class CameraMock extends Camera {

    /**
     * Remove intermediate image files that are kept in temporary storage after calling camera.getPicture.
     *
     * @return Promise resolved when done.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    cleanup(): Promise<any> {
        // This function is iOS only, nothing to do.
        return Promise.resolve();
    }

    /**
     * Take a picture.
     *
     * @param options Options that you want to pass to the camera.
     * @return Promise resolved when captured.
     */
    getPicture(options: CameraOptions): Promise<string> {
        return CoreEmulatorCaptureHelper.captureMedia('image', options);
    }

}
